

local major, minor, libTable = LibStub("LibBuilder-1.0"):GetLib()
if not libTable.canLoad then return end


local interface = libTable.interface


---	Creates a scriptlink using only the most common options.
--	@param	callback	Callback function or script to call when the link is clicked.
--	@param	label		Optional text label for the scriptlink. Include brackets if you 
--						want them. Defaults to "[Click Here]".
--	@param	color		Color string for the link. Defaults to "ffffff33". If you want to 
--						use the default color but your label looks like a color string, 
--						use the form :NewLink(callback, label, "").
--	@return	scriptlink	The new scriptlink (a string).
function interface:NewLink(callback, label, color)
	assert(type(callback) == "function" or type(callback)=="string")
	assert(not label or type(label) == "string")
	assert(not color or type(color) == "string")
	
	if color == nil then
		--	if label looks like a color string, move it over
		if label and label:match("%x%x%x%x%x%x%x%x") then
			color = label
			label = nil
		end
	end
	
	if color == "" then
		color = nil
	end

	--	LinkBuilder will replace the nils with defaults

	local linkBuilder = libTable.classes.LinkBuilder:New()
	
	linkBuilder:SetCallback(callback)
	linkBuilder:SetLabel(label)
	linkBuilder:SetColor(color)
	
	return linkBuilder:Build()
end


---	Retrieves a new LinkBuilder object, allowing direct access to link features.
--	@return linkBuilder	The new LinkBuilder object.
function interface:NewLinkBuilder()
	return libTable.classes.LinkBuilder:New()
end


--	activates all function hooks
function interface:Enable()
	libTable.classes.Core:HookAll()
end

--	deactivates all function hooks
function interface:Disable()
	libTable.classes.Core:UnhookAll()
end
